## Python curses utility to cycle between desktop wallpapers

Currently the script handles only XFCE and LightDM

## Contribute!
### TODO:

**Need help expanding it to work with other DE's , DM's and LightDM greeters !**

For reference, a similar script for Gnome: 
[wallpyper](https://github.com/unwitting/wallpyper)

And here's a Windows script that downloads and sets the image of the day:
[wallpy](https://github.com/MMartin09/wallpy)

## Installation:

Current requirements are:
 - xorg-xrandr: Screen discovery

### Install:

    # Via PIP:
    $ pip install waller


    # From Arch AUR repo:
    $ ... -S waller

### Run:

    $ waller

**Please leave feedback and ideas on the [issues](https://github.com/codeswhite/waller/issues) page :)**
